![Linux](https://img.shields.io/badge/-Linux-grey?logo=linux)
![Usage](https://img.shields.io/badge/Usage-Terminal%20User%20Interface-yellow)
![Python](https://img.shields.io/badge/Python-v3.8%5E-green?logo=python)
![pyTermTk_version](https://img.shields.io/github/v/tag/ceccopierangiolieugenio/pyTermTk?label=version)
[![Test Status](https://img.shields.io/github/actions/workflow/status/ceccopierangiolieugenio/pyTermTk/testing.yml?branch=main&label=tests)](https://github.com/ceccopierangiolieugenio/pyTermTk/actions?query=workflow%3Atesting)
[![pypi_version](https://img.shields.io/pypi/v/ttkDesigner?label=pypi)](https://pypi.org/project/ttkDesigner)
[![pypi_version](https://img.shields.io/twitter/follow/Pier95886803?style=social&logo=twitter)](https://twitter.com/hashtag/pyTermTk?src=hashtag_click&f=live)

[![screenshot](https://user-images.githubusercontent.com/8876552/236525667-dcdcec6e-1066-4294-bdb0-db98ef8850da.png)](https://pypi.org/project/ttkDesigner)

## [ttkDesigner](https://github.com/ceccopierangiolieugenio/pyTermTk/tree/main/ttkDesigner)

**ttkDesigner** is the [pyTermTk](https://github.com/ceccopierangiolieugenio/pyTermTk) tool for designing and building Text-based user interfaces ([TUI](https://en.wikipedia.org/wiki/Text-based_user_interface)s) with [pyTermTk](https://github.com/ceccopierangiolieugenio/pyTermTk) Widgets. You can compose and customize your windows or dialogs in a what-you-see-is-what-you-get (WYSIWYG) manner, and test them interactively.

Widgets and forms created with **ttkDesigner** integrate seamlessly with programmed code, using [pyTermTk](https://github.com/ceccopierangiolieugenio/pyTermTk)'s signals and slots mechanism, so that you can easily assign behavior to graphical elements. All properties set in **ttkDesigner** can be changed dynamically within the code.

## Features
tbd

## Install/Upgrade
[ttkDesigner](https://github.com/ceccopierangiolieugenio/pyTermTk/tree/main/ttkDesigner)
 is available on [PyPI](https://pypi.org/project/ttkDesigner/)
```bash
pip3 install --upgrade ttkDesigner
```
## Run
```bash
ttkDesigner
```
